package com.dky.calculate;


import com.dky.utils.enums.EnergyPriceType;

public class KitchenCookModel {

    private static final double ELECTIRC_PRICE_KILOWATT_HOUR = EnergyPriceType.Residential_Electric_Price.getPrice(); // 居民平均电价(0.55元/千瓦时)
    private static final double COAL_PRICE_PER_KILOGRAM = 0.9; // 煤炭的平均价格，单位：元/千克
    private static final double STANDARD_COAL_CONVERSION_FACTOR = 0.7143; // 千克标准煤/千克
    private static final double CO2_CONVERSION_FACTOR = 1.9003; // 千克二氧化碳/千克
    private static final double ELECTRICITY_SUBSTITUTION_CONVERSION_FACTOR = 0.1229; // 千克标准煤/千瓦时

    /**
     * 计算电厨炊年耗电量
     * @param powerPerUnit 设备功率
     * @param numberOfUnits 设备台数
     * @param annualOperatingHours 电设备年运行时间
     * @return 单台电厨炊的功率<A> * 电厨炊设备台数 * 电设备年运行时间<B>
     */
    public static double calculateAnnualElectricityConsumption(double powerPerUnit, int numberOfUnits, int annualOperatingHours) {
        return powerPerUnit * numberOfUnits * annualOperatingHours;
    }

    /**
     * 计算年运行费用
     * @param powerPerUnit 设备功率
     * @param numberOfUnits 设备台数
     * @param annualOperatingHours 电设备年运行时间
     * @param laborCostForReplacement 电替代设备人工费用成本
     * @return 电厨炊年耗电量 *平均电价(0.55元/千瓦时) + 电替代设备人工费用成本<A>
     */
    public static double calculateAnnualOperatingCost(double powerPerUnit, int numberOfUnits, int annualOperatingHours, double laborCostForReplacement) {
        return calculateAnnualElectricityConsumption(powerPerUnit, numberOfUnits, annualOperatingHours) * ELECTIRC_PRICE_KILOWATT_HOUR + laborCostForReplacement;
    }

    /**
     * 计算总年费用
     * @param numberOfUnits 电厨炊设备台数
     * @param pricePerUnit 单台电设备价格
     * @param usefulLifeYears 电厨炊的使用年限
     * @param powerPerUnit 设备功率
     * @param annualOperatingHours 电设备年运行时间
     * @param laborCostForReplacement 电替代设备人工费用成本
     * @return (电厨炊设备台数 *单台电设备价格<A>）/电厨炊的使用年限<A> + 年运行费用
     */
    public static double calculateTotalAnnualCost(int numberOfUnits, double pricePerUnit, int usefulLifeYears, double powerPerUnit, int annualOperatingHours, double laborCostForReplacement) {
        double initialCost = numberOfUnits * pricePerUnit;
        double depreciationCost = initialCost / usefulLifeYears;
        return depreciationCost + calculateAnnualOperatingCost(powerPerUnit, numberOfUnits, annualOperatingHours, laborCostForReplacement);
    }

    /**
     * 计算年减碳量
     * @param lastYearFee 上年运行费用
     * @param laborCostForOriginalDevice  原设备人工费用
     * @param annualElectricityConsumption 电替代设备年耗电量
     * @return 年减碳量=[（上年运行费用-原设备的人工费用）/煤炭平均价格(0.9元/千克)*0.7143千克标准煤/千克-电替代设备年耗电量*0.1229千克标准煤/千瓦时]*1.9003千克二氧化碳/千克
     */
    public static double calculateAnnualCarbonReduction(double lastYearFee, double laborCostForOriginalDevice, double annualElectricityConsumption) {
        // （上年运行费用-原设备的人工费用）/煤炭平均价格(0.9元/千克)*0.7143千克标准煤/千克
        double coalEquivalentFromPreviousYear = (lastYearFee - laborCostForOriginalDevice) / COAL_PRICE_PER_KILOGRAM * STANDARD_COAL_CONVERSION_FACTOR;
        // 电替代设备年耗电量 * 0.1229千克标准煤
        double electricityEquivalent = annualElectricityConsumption * ELECTRICITY_SUBSTITUTION_CONVERSION_FACTOR;
        // （上年运行费用-原设备的人工费用）/煤炭平均价格(0.9元/千克)*0.7143千克标准煤/千克-电替代设备年耗电量*0.1229千克标准煤/千瓦时
        double netReductionInCoalEquivalent = coalEquivalentFromPreviousYear - electricityEquivalent;
        return netReductionInCoalEquivalent * CO2_CONVERSION_FACTOR;
    }

}
